@@ -34,6 +34,10 @@ class DataSetter:
                                         "DiscrepancyCode": str(data['notaDiscrepanciaCode']),
                                         "Currency": str(data['tipoMoneda'])
                                     }
+        if(str(data["exportacion"]["exportation"]["es_exportacion"]) == str("True")):        
+                note_general_information["ExchangeRate"] = str(data["exportacion"]["exportation"]["calculo_rate"])
+                note_general_information["ExchangeRateDate"] = str(data["exportacion"]["exportation"]["calculation_date"])
+                
         return note_general_information
 
     def fill_CustomerInformation(self, data):
